@@ -3,7 +3,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '1.026';
+our $VERSION = '1.027';
 
 =head1 NAME
 
@@ -675,6 +675,11 @@ sub pack_manifest_hash {
     my (@modules, @data, @exclude);
 
     foreach my $name (@{ $opt->{M} || [] }) {
+        # for "-M Foo::Bar::" also add everything below .../Foo/Bar
+        if ($name =~ s/^([\w:]+)::$/$1/) {
+            (my $mod = $name) =~ s/::/\//g;
+            Module::ScanDeps::add_preload_rule("$mod.pm", 'sub');
+        }
         $self->_name2moddata($name, \@modules, \@data);
     }
 
@@ -718,16 +723,16 @@ sub pack_manifest_hash {
           or $self->_die("Cannot find module $module (specified with -M)\n");
         push @files, $file;
         
-        my $preload = Module::ScanDeps::_get_preload($module) or next;
+        my @preload = Module::ScanDeps::_get_preload($module) or next;
         
         $add_deps->(
             used_by => $file,
             rv      => \%map,
-            modules => $preload,
+            modules => \@preload,
             skip    => \%skip,
 #            warn_missing => $args->{warn_missing},
         );
-        push @files, map {&$inc_find($_)} @$preload;
+        push @files, map {&$inc_find($_)} @preload;
     }
     push @files, @$input;
 
