@@ -1,5 +1,5 @@
 package PAR::StrippedPARL::Base;
-use 5.006;
+use 5.008001;
 use strict;
 use warnings;
 our $VERSION = '0.975';
@@ -53,10 +53,7 @@ sub write_parl {
 
     # write out to a temporary file first
     my ($fh, $tfile) = File::Temp::tempfile(
-        "parlXXXX",
-        SUFFIX => $Config::Config{_exe}||'',
-        DIR => File::Spec->tmpdir(),
-    );
+        "parlXXXX", SUFFIX => $Config::Config{_exe}||'', TMPDIR => 1);
     close $fh;
     # File::Temp, you suck!
 
@@ -70,6 +67,7 @@ sub write_parl {
     # Use this to generate a real parl
     my @libs = ();
     for my $ilib ( @INC ) {
+        next if ref $ilib;
         $ilib =~ s/\\$/\\\\/;
         push(@libs, qq(-I$ilib) );
     }
